@@ -88,6 +88,11 @@ from vessl.organization import (
     read_organization,
 )
 from vessl.project import create_project, list_projects, read_project
+from vessl.service import (
+    RunnerBase,
+    register_model,
+    register_torch_model,
+)
 from vessl.ssh_key import create_ssh_key, delete_ssh_key, list_ssh_keys
 from vessl.sweep import (
     create_sweep,
