@@ -3,7 +3,7 @@ from typing import List
 from openapi_client import (
     ModelRepositoryCreateAPIInput,
     ModelRepositoryUpdateAPIInput,
-    ResponseFileMetadata,
+    StorageFile,
     ResponseModelRepositoryDetail,
 )
 from openapi_client.models import (
@@ -283,7 +283,7 @@ def list_model_volume_files(
     path: str = "",
     recursive: bool = False,
     **kwargs,
-) -> List[ResponseFileMetadata]:
+) -> List[StorageFile]:
     """List model files in the default organization. If you want to override the
     default organization, then pass `organization_name` as `**kwargs`.
 
@@ -392,9 +392,8 @@ def delete_model_volume_file(
     repository_name: str,
     model_number: int,
     path: str,
-    recursive: bool = False,
     **kwargs,
-) -> List[ResponseFileMetadata]:
+):
     """Delete the model volume file in the default organization. If you want to
     override the default organization, then pass `organization_name` as
     `**kwargs`.
@@ -403,8 +402,6 @@ def delete_model_volume_file(
         repository_name(str): Model repository name.
         model_number(int): Model number.
         path(str): File path within the model
-        recursive(bool): True if file is a directory, False otherwise. Defaults
-            to False.
 
     Example:
         ```python
@@ -419,4 +416,4 @@ def delete_model_volume_file(
     model = read_model(
         repository_name=repository_name, model_number=model_number, **kwargs
     )
-    return delete_volume_file(model.artifact_volume_id, path, recursive)
+    delete_volume_file(model.artifact_volume_id, path)
